@@ -8,6 +8,7 @@ from .. import Logger
 from .base_api_client import BaseApiClient
 from ..exceptions.reporter import ReporterException
 from ..models import Attachment, Result, Step
+from ..models.config.framework import Video, Trace
 from ..models.config.qaseconfig import QaseConfig
 from ..models.step import StepType
 
@@ -137,9 +138,11 @@ class ApiV1Client(BaseApiClient):
         attached = []
         if result.attachments:
             for attachment in result.attachments:
+                if self.__should_skip_attachment(attachment, result):
+                    continue
                 attach_id = self._upload_attachment(project_code, attachment)
                 if attach_id:
-                    attached.append(attach_id)
+                    attached.extend(attach_id)
 
         steps = []
         for step in result.steps:
@@ -168,8 +171,14 @@ class ApiV1Client(BaseApiClient):
             case_data["layer"] = result.get_field('layer')
 
         suite = None
-        if result.get_suite_title():
-            suite = "\t".join(result.get_suite_title().split("."))
+        if result.relations is not None and result.relations.suite is not None and len(
+                result.relations.suite.data) != 0:
+            suites = []
+
+            for raw in result.relations.suite.data:
+                suites.append(raw.title)
+
+            suite = "\t".join(suites)
 
         if result.get_field('suite'):
             suite = result.get_field('suite')
@@ -254,7 +263,7 @@ class ApiV1Client(BaseApiClient):
                 for file in step.attachments:
                     attach_id = self._upload_attachment(project_code, file)
                     if attach_id:
-                        uploaded_attachments.append(attach_id)
+                        uploaded_attachments.extend(attach_id)
                 prepared_step['attachments'] = [attach.hash for attach in uploaded_attachments]
 
             if step.steps:
@@ -278,3 +287,14 @@ class ApiV1Client(BaseApiClient):
         self.__authors[author] = authors.result.entities[0].author_id
 
         return authors.result.entities[0].author_id
+
+    def __should_skip_attachment(self, attachment, result):
+        if (self.config.framework.playwright.video == Video.failed and
+                result.execution.status != 'failed' and
+                attachment.file_name == 'video.webm'):
+            return True
+        if (self.config.framework.playwright.trace == Trace.failed and
+                result.execution.status != 'failed' and
+                attachment.file_name == 'trace.zip'):
+            return True
+        return False
